@@ -3,7 +3,7 @@
 # Filename: AutoInit_GBase8s.sh
 # Function: Auto install GBase 8s software and auto init database.
 # Write by: liaosnet@gbasedbt.com
-# Version : 1.4.12   update date: 2024-12-11
+# Version : 1.4.13   update date: 2025-05-23
 ##################################################################
 ##### Defind env
 export LANG=C
@@ -55,10 +55,10 @@ done
 ##### Define Parameter
 USER_NAME=${USER_NAME:-gbasedbt}
 if [ x"$USER_NAME" = "xgbasedbt" -o x"$USER_NAME" = "xinformix" ]; then
-   _loginfo "The SYSDBA user is: $USER_NAME"
+  _loginfo "The SYSDBA user is: $USER_NAME"
 else
-   echo "Username error!"
-   exit 1
+  echo "Username error!"
+  exit 1
 fi
 USER_UPPER=$(echo $USER_NAME|tr "[a-z]" "[A-Z]")
 USER_HOME=${USER_HOME:-/home/gbase}
@@ -105,11 +105,30 @@ if [ x"$SOFTPACKNAME" = x ]; then
   _loginfo "ERROR: GBase Database Soft Package not found."
   exit 2
 fi
+# check cpu arch & software 
+# todo: other cpu
+CPUTYPE=$(uname -m)
+SOFTCPU=$(echo "${SOFTPACKNAME}" | awk '
+    BEGIN{IGNORECASE=1}
+    {if(/FT|KP9/){print "aarch64";exit}
+     else if(/SW/){print "sw64";exit}
+     else if(/Loongson/){print "loongarch64";exit}
+     else {print "x86_64"}
+    }')	 
+
+if [ x"${CPUTYPE}" = "xx86_64" -o x"${CPUTYPE}" = "xaarch64" ]; then 
+  if [ ! x"${CPUTYPE}" = x"${SOFTCPU}" ]; then 
+    _loginfo "ERROR: Current CPU type is: ${CPUTYPE}, BUT software package is: ${SOFTCPU} "
+    exit 2
+  fi
+else
+  _loginfo "Current CPU type is: ${CPUTYPE}, Software package is: ${SOFTCPU} "
+fi							
 
 ### CheckEnv.sh
 bash CheckEnv.sh
 if [ $? -gt 0 ]; then
-    exit 3
+  exit 3
 fi
 
 # IP use first IPADDR
@@ -214,8 +233,8 @@ CFG_SHMTOTAL=$(expr $NUMMEM \* 900)
 ##### Create group and user
 id ${USER_NAME} >/dev/null 2>&1
 if [ $? -eq 0 ];then
-    echo "User: ${USER_NAME} exists, you must check !" 
-    exit 2
+  echo "User: ${USER_NAME} exists, you must check !" 
+  exit 2
 fi
 _loginfo "Creating group [${USER_NAME}] and user [${USER_NAME}] with HOME [$USER_HOME]."
 groupadd ${USER_NAME} 2>/dev/null
@@ -371,7 +390,7 @@ if [ "x$SOFTONLY" = xy -o "x$SOFTONLY" = xY ];then
 fi
 
 # fix 330 ddlalert error
-_loginfo "Creating file \$INSTALL_DIR/etc/upgraded ."
+_loginfo "Creating file $INSTALL_DIR/etc/upgraded ."
 if [ ! -f $INSTALL_DIR/etc/upgraded ]; then
   touch $INSTALL_DIR/etc/upgraded
   chown ${USER_NAME}:${USER_NAME} $INSTALL_DIR/etc/upgraded
@@ -440,12 +459,12 @@ where tk_name = 'idle_user_timeout';
 -- procedure
 drop procedure if exists delete_task_logs;
 create procedure delete_task_logs()
-  define v_datestr varchar(40);
+  define v_datestr datetime year to second;
   select current year to second - value::interval day to second
   into v_datestr
   from ph_threshold
   where task_name = 'delete_task_logs';
-  if v_datestr is null OR v_datestr <> '' then
+  if v_datestr is not null AND v_datestr <> '' then
     delete from command_history where cmd_exec_time < v_datestr;
     delete from ph_run where run_time < v_datestr;
     -- delete from ph_alerts where alert_time < v_datestr;
@@ -556,7 +575,7 @@ sed -i "s#^DS_NONPDQ_QUERY_MEM.*#DS_NONPDQ_QUERY_MEM 256000#g" $CFGFILE
 sed -i "s#^TEMPTAB_NOLOG.*#TEMPTAB_NOLOG 1#g" $CFGFILE
 sed -i "s#^DUMPSHMEM.*#DUMPSHMEM 0#g" $CFGFILE
 # sed -i "s#^IFX_FOLDVIEW.*#IFX_FOLDVIEW 0#g" $CFGFILE
-sed -i "s#^OPT_GOAL.*#OPT_GOAL 0#g" $CFGFILE
+# sed -i "s#^OPT_GOAL.*#OPT_GOAL 0#g" $CFGFILE
 sed -i "s#^TAPEBLK.*#TAPEBLK 512#g" $CFGFILE
 sed -i "s#^LTAPEBLK.*#LTAPEBLK 512#g" $CFGFILE
 sed -i "s#^ALARMPROGRAM.*#ALARMPROGRAM \$GBASEDBTDIR/etc/log_full.sh#g" $CFGFILE
